==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/WarrantyCoverage.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYCOVERAGESEQNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WarrantyCoverage_001}EquipmentWarranty"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "warrantycoverageseqnum",
    "equipmentWarranty"
})
@XmlRootElement(name = "WarrantyCoverage")
public class WarrantyCoverage {

    @XmlElement(name = "WARRANTYCOVERAGESEQNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected long warrantycoverageseqnum;
    @XmlElement(name = "EquipmentWarranty", required = true)
    protected EquipmentWarranty equipmentWarranty;

    /**
     * Obtient la valeur de la propriété warrantycoverageseqnum.
     * 
     */
    public long getWARRANTYCOVERAGESEQNUM() {
        return warrantycoverageseqnum;
    }

    /**
     * Définit la valeur de la propriété warrantycoverageseqnum.
     * 
     */
    public void setWARRANTYCOVERAGESEQNUM(long value) {
        this.warrantycoverageseqnum = value;
    }

    /**
     * Obtient la valeur de la propriété equipmentWarranty.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentWarranty }
     *     
     */
    public EquipmentWarranty getEquipmentWarranty() {
        return equipmentWarranty;
    }

    /**
     * Définit la valeur de la propriété equipmentWarranty.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentWarranty }
     *     
     */
    public void setEquipmentWarranty(EquipmentWarranty value) {
        this.equipmentWarranty = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/warrantycoverage_001/WarrantyCoverage.java <==

package net.datastream.schemas.mp_entities.warrantycoverage_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WARRANTYCOVERAGESEQNUM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_entities/WarrantyCoverage_001}EquipmentWarranty"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "warrantycoverageseqnum",
    "equipmentWarranty"
})
@XmlRootElement(name = "WarrantyCoverage")
public class WarrantyCoverage {

    @XmlElement(name = "WARRANTYCOVERAGESEQNUM", namespace = "http://schemas.datastream.net/MP_fields")
    protected long warrantycoverageseqnum;
    @XmlElement(name = "EquipmentWarranty", required = true)
    protected EquipmentWarranty equipmentWarranty;

    /**
     * Gets the value of the warrantycoverageseqnum property.
     * 
     */
    public long getWARRANTYCOVERAGESEQNUM() {
        return warrantycoverageseqnum;
    }

    /**
     * Sets the value of the warrantycoverageseqnum property.
     * 
     */
    public void setWARRANTYCOVERAGESEQNUM(long value) {
        this.warrantycoverageseqnum = value;
    }

    /**
     * Gets the value of the equipmentWarranty property.
     * 
     * @return
     *     possible object is
     *     {@link EquipmentWarranty }
     *     
     */
    public EquipmentWarranty getEquipmentWarranty() {
        return equipmentWarranty;
    }

    /**
     * Sets the value of the equipmentWarranty property.
     * 
     * @param value
     *     allowed object is
     *     {@link EquipmentWarranty }
     *     
     */
    public void setEquipmentWarranty(EquipmentWarranty value) {
        this.equipmentWarranty = value;
    }

}
